(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', './Day', '../util'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('./Day'), require('../util'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.Day, global.util);
        global.Month = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _Day, _util) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Day2 = _interopRequireDefault(_Day);

    var DateTime = _interopRequireWildcard(_util);

    function _interopRequireWildcard(obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    }

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    var _createClass = function () {
        function defineProperties(target, props) {
            for (var i = 0; i < props.length; i++) {
                var descriptor = props[i];
                descriptor.enumerable = descriptor.enumerable || false;
                descriptor.configurable = true;
                if ("value" in descriptor) descriptor.writable = true;
                Object.defineProperty(target, descriptor.key, descriptor);
            }
        }

        return function (Constructor, protoProps, staticProps) {
            if (protoProps) defineProperties(Constructor.prototype, protoProps);
            if (staticProps) defineProperties(Constructor, staticProps);
            return Constructor;
        };
    }();

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('CalendarMonth');

    /**
     * melon-calendar 日期选择面板
     *
     * @class
     * @extends {React.Component}
     */

    var CalendarMonth = function (_Component) {
        _inherits(CalendarMonth, _Component);

        /**
         * 构造函数
         *
         * @param  {Object} props   组件属性
         * @public
         */
        function CalendarMonth(props) {
            _classCallCheck(this, CalendarMonth);

            var _this = _possibleConstructorReturn(this, (CalendarMonth.__proto__ || Object.getPrototypeOf(CalendarMonth)).call(this, props));

            _this.onClick = _this.onClick.bind(_this);
            _this.renderWeek = _this.renderWeek.bind(_this);
            _this.renderDay = _this.renderDay.bind(_this);
            return _this;
        }

        /**
         * 点击某一天的按钮时触发
         *
         * @param  {Object} e 事件对象
         */


        _createClass(CalendarMonth, [{
            key: 'onClick',
            value: function onClick(e) {
                var onChange = this.props.onChange;
                if (onChange) {
                    onChange({
                        target: this,
                        date: e.date
                    });
                }
            }
        }, {
            key: 'renderWeekHeader',
            value: function renderWeekHeader() {
                var days = this.props.lang.days.split(',');

                return _react2.default.createElement(
                    'div',
                    { className: cx.getPartClassName('weekheader') },
                    days.map(function (day, index) {
                        return _react2.default.createElement(
                            'span',
                            { key: index },
                            day
                        );
                    })
                );
            }
        }, {
            key: 'renderDates',
            value: function renderDates() {

                var month = this.props.month;

                var weekArray = DateTime.getFullWeekArray(month);

                return _react2.default.createElement(
                    'ul',
                    null,
                    weekArray.map(this.renderWeek)
                );
            }
        }, {
            key: 'renderWeek',
            value: function renderWeek(week, index) {

                return _react2.default.createElement(
                    'li',
                    { key: index, className: cx().part('week').build() },
                    week.map(this.renderDay)
                );
            }
        }, {
            key: 'renderDay',
            value: function renderDay(day, index) {
                var _props = this.props,
                    date = _props.date,
                    minDate = _props.minDate,
                    maxDate = _props.maxDate;


                var selected = DateTime.isEqualDate(day.date, date);
                var disabled = DateTime.isDate(minDate) && DateTime.isBeforeDate(day.date, minDate) || DateTime.isDate(maxDate) && DateTime.isAfterDate(day.date, maxDate);

                return _react2.default.createElement(_Day2.default, {
                    key: day.date,
                    date: day.date,
                    variants: day.variants,
                    disabled: disabled,
                    selected: selected,
                    onClick: this.onClick });
            }
        }, {
            key: 'render',
            value: function render() {

                return _react2.default.createElement(
                    'div',
                    { className: cx(this.props).build() },
                    this.renderWeekHeader(),
                    this.renderDates()
                );
            }
        }]);

        return CalendarMonth;
    }(_react.Component);

    exports.default = CalendarMonth;


    CalendarMonth.displayName = 'CalendarMonth';

    CalendarMonth.propTypes = {
        date: _propTypes2.default.object.isRequired,
        month: _propTypes2.default.object.isRequired,
        maxDate: _propTypes2.default.object,
        minDate: _propTypes2.default.object,
        onChange: _propTypes2.default.func,
        lang: _propTypes2.default.shape({
            week: _propTypes2.default.string,
            days: _propTypes2.default.string
        }).isRequired
    };
});
//# sourceMappingURL=Month.js.map
