(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', 'melon/Icon', '../util'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('melon/Icon'), require('../util'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.Icon, global.util);
        global.Pager = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _Icon, _util) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Icon2 = _interopRequireDefault(_Icon);

    var DateTime = _interopRequireWildcard(_util);

    function _interopRequireWildcard(obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    }

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    var _createClass = function () {
        function defineProperties(target, props) {
            for (var i = 0; i < props.length; i++) {
                var descriptor = props[i];
                descriptor.enumerable = descriptor.enumerable || false;
                descriptor.configurable = true;
                if ("value" in descriptor) descriptor.writable = true;
                Object.defineProperty(target, descriptor.key, descriptor);
            }
        }

        return function (Constructor, protoProps, staticProps) {
            if (protoProps) defineProperties(Constructor.prototype, protoProps);
            if (staticProps) defineProperties(Constructor, staticProps);
            return Constructor;
        };
    }();

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('CalendarPager');

    /**
     * melon-calendar 日期翻页器
     *
     * @class
     * @extends {React.Component}
     */

    var CalendarPager = function (_Component) {
        _inherits(CalendarPager, _Component);

        /**
         * 构造函数
         *
         * @param  {Object} props   组件属性
         * @public
         */
        function CalendarPager(props) {
            _classCallCheck(this, CalendarPager);

            var _this = _possibleConstructorReturn(this, (CalendarPager.__proto__ || Object.getPrototypeOf(CalendarPager)).call(this, props));

            _this.onClick = _this.onClick.bind(_this);
            return _this;
        }

        /**
         * 点击翻页事件
         *
         * @param  {Object} e   事件对象
         * @private
         */


        _createClass(CalendarPager, [{
            key: 'onClick',
            value: function onClick(e) {

                var target = e.currentTarget;
                var month = this.props.month;

                var action = target.getAttribute('data-action');
                var newMonth = DateTime.addMonths(month, action === 'next' ? 1 : -1);

                var onChange = this.props.onChange;

                if (onChange) {
                    onChange({
                        target: this,
                        month: newMonth
                    });
                }
            }
        }, {
            key: 'render',
            value: function render() {
                var _props = this.props,
                    maxDate = _props.maxDate,
                    minDate = _props.minDate,
                    month = _props.month;


                var m = month.getMonth() + 1;
                var y = month.getFullYear();

                var beforeState = {
                    disabled: DateTime.isDate(minDate) && DateTime.isBeforeMonth(DateTime.addMonths(month, -1), minDate)
                };

                var nextState = {
                    disabled: DateTime.isDate(maxDate) && DateTime.isAfterMonth(DateTime.addMonths(month, 1), maxDate)
                };

                return _react2.default.createElement(
                    'div',
                    { className: cx(this.props).build() },
                    _react2.default.createElement(_Icon2.default, {
                        icon: 'navigate-before',
                        'data-role': 'pager',
                        className: cx().part('prev').addStates(beforeState).build(),
                        'data-action': 'prev',
                        onClick: beforeState.disabled ? null : this.onClick }),
                    _react2.default.createElement(_Icon2.default, {
                        icon: 'navigate-next',
                        'data-role': 'pager',
                        className: cx().part('next').addStates(nextState).build(),
                        'data-action': 'next',
                        onClick: nextState.disabled ? null : this.onClick }),
                    y + ' 年 ' + m + ' 月'
                );
            }
        }]);

        return CalendarPager;
    }(_react.Component);

    exports.default = CalendarPager;


    CalendarPager.displayName = 'CalendarPager';

    CalendarPager.propTypes = {
        month: _propTypes2.default.object.isRequired,
        maxDate: _propTypes2.default.object,
        minDate: _propTypes2.default.object,
        onChange: _propTypes2.default.func
    };
});
//# sourceMappingURL=Pager.js.map
