(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'react-dom', 'melon-core/classname/cxBuilder', './SelectorItem', '../util', 'melon-core/util/array'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('react-dom'), require('melon-core/classname/cxBuilder'), require('./SelectorItem'), require('../util'), require('melon-core/util/array'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.reactDom, global.cxBuilder, global.SelectorItem, global.util, global.array);
        global.Selector = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _reactDom, _cxBuilder, _SelectorItem, _util, _array) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _reactDom2 = _interopRequireDefault(_reactDom);

    var _SelectorItem2 = _interopRequireDefault(_SelectorItem);

    var DateTime = _interopRequireWildcard(_util);

    function _interopRequireWildcard(obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    }

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _objectWithoutProperties(obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    var _createClass = function () {
        function defineProperties(target, props) {
            for (var i = 0; i < props.length; i++) {
                var descriptor = props[i];
                descriptor.enumerable = descriptor.enumerable || false;
                descriptor.configurable = true;
                if ("value" in descriptor) descriptor.writable = true;
                Object.defineProperty(target, descriptor.key, descriptor);
            }
        }

        return function (Constructor, protoProps, staticProps) {
            if (protoProps) defineProperties(Constructor.prototype, protoProps);
            if (staticProps) defineProperties(Constructor, staticProps);
            return Constructor;
        };
    }();

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('CalendarSelector');

    /**
     * melon-calendar 年/月选择面板
     *
     * @class
     * @extends {React.Component}
     */

    var CalendarSelector = function (_Component) {
        _inherits(CalendarSelector, _Component);

        /**
         * 构造函数
         *
         * @param  {Object} props   组件属性
         * @public
         */
        function CalendarSelector(props) {
            _classCallCheck(this, CalendarSelector);

            var _this = _possibleConstructorReturn(this, (CalendarSelector.__proto__ || Object.getPrototypeOf(CalendarSelector)).call(this, props));

            _this.componentDidMount = _this.autoScroll;
            _this.componentDidUpdate = _this.autoScroll;

            _this.onClick = _this.onClick.bind(_this);
            return _this;
        }

        /**
         * 组件mount时触发，当前选择的年/月需要在可见范围
         *
         * @public
         */


        /**
         * 组件更新时触发，当前选择的年/月需要在可见范围
         *
         * @public
         */


        _createClass(CalendarSelector, [{
            key: 'autoScroll',
            value: function autoScroll() {
                var item = this.refs.item ? _reactDom2.default.findDOMNode(this.refs.item) : null;
                item && item.scrollIntoView && item.scrollIntoView();
            }
        }, {
            key: 'onClick',
            value: function onClick(e) {

                var onChange = this.props.onChange;

                if (onChange) {
                    onChange({
                        target: this,
                        mode: e.mode,
                        date: e.date
                    });
                }
            }
        }, {
            key: 'isMonthView',
            value: function isMonthView() {
                var _props = this.props,
                    minDate = _props.minDate,
                    maxDate = _props.maxDate,
                    mode = _props.mode;


                var onlyOneYear = false;

                // 如果范围中只有一年，则跳过yearview，直接显示month view
                if (mode === 'year' && DateTime.isDate(minDate) && DateTime.isDate(maxDate)) {
                    onlyOneYear = DateTime.yearDiff(minDate, maxDate) === 0;
                }

                return mode === 'month' || onlyOneYear;
            }
        }, {
            key: 'render',
            value: function render() {
                var _this2 = this;

                var _props2 = this.props,
                    minDate = _props2.minDate,
                    maxDate = _props2.maxDate,
                    date = _props2.date,
                    rest = _objectWithoutProperties(_props2, ['minDate', 'maxDate', 'date']);

                var children = [];

                var y = date.getFullYear();
                var m = date.getMonth();
                var d = date.getDate();

                if (this.isMonthView()) {
                    children = (0, _array.range)(12).map(function (month, index) {

                        var newDate = new Date(y, month, d);
                        var disabled = DateTime.isDate(minDate) && DateTime.isBeforeMonth(newDate, minDate) || DateTime.isDate(maxDate) && DateTime.isAfterMonth(newDate, maxDate);
                        var selected = month === m;

                        return _react2.default.createElement(_SelectorItem2.default, {
                            key: index,
                            mode: 'month',
                            ref: selected ? 'item' : null,
                            date: newDate,
                            onClick: _this2.onClick,
                            disabled: disabled,
                            selected: selected });
                    });
                } else {

                    var maxRange = CalendarSelector.MAX_RANGE;

                    (0, _array.range)(y - maxRange, y + maxRange).forEach(function (year, index) {

                        if (DateTime.isDate(minDate) && year < minDate.getFullYear() || DateTime.isDate(maxDate) && year > maxDate.getFullYear()) {

                            return;
                        }

                        var newDate = new Date(year, m, d);
                        var selected = year === y;

                        children.push(_react2.default.createElement(_SelectorItem2.default, {
                            key: index,
                            mode: 'year',
                            ref: selected ? 'item' : null,
                            date: newDate,
                            onClick: _this2.onClick,
                            selected: selected }));
                    });
                }

                return _react2.default.createElement(
                    'ul',
                    _extends({}, rest, { className: cx(this.props).build() }),
                    children
                );
            }
        }]);

        return CalendarSelector;
    }(_react.Component);

    exports.default = CalendarSelector;


    CalendarSelector.displayName = 'CalendarSelector';

    CalendarSelector.MAX_RANGE = 10;

    CalendarSelector.propTypes = {
        date: _propTypes2.default.object.isRequired,
        maxDate: _propTypes2.default.object,
        minDate: _propTypes2.default.object,
        onChange: _propTypes2.default.func,
        mode: _propTypes2.default.oneOf(['month', 'year'])
    };
});
//# sourceMappingURL=Selector.js.map
